﻿-- Author      : Potdisc
-- Create Date : 3/23/2012 4:37:15 PM
-- LootFrame.lua
-- Gets info from MainFrame.lua and displays looting options for the player

local MAX_LOOTS = 10;
local db, buttonsDB;
local itemsLooting = {}
local _;

-------------- OnLoad -------------------
-- Creates all the loot frames and buttons
-- when the addon is loaded.
-----------------------------------------
function RCLootCouncil_LootFrame:OnLoad()
	db = RCLootCouncil:GetVariable("mlDB")
	buttonsDB = db.buttons
	-- lootframe
	local frame = CreateFrame("Frame", "$parentEntry1", RCLootFrame, "RCLootFrameEntry")
	frame:SetID(1)
	frame:SetPoint("TOPLEFT", RCLootFrame, "TOPLEFT")
	frame:Show()
	-- lootframe buttons
	local button = CreateFrame("Button", "$parentButton1", frame, "RCLootFrame_Button"); -- Creates the first row
	button:SetID(1); -- Set the ID
	button:SetPoint("TOPLEFT", 68, -42) -- Set anchor
	button:SetWidth(66) -- set the length
	for i = 2, db.maxButtons do -- Create the rest of the buttons
		button = CreateFrame("Button", "$parentButton"..i, frame, "RCLootFrame_Button");
		button:SetWidth(66)
		button:SetID(i);
		button:SetPoint("TOPLEFT", "$parentButton"..(i-1), "TOPRIGHT", 5, 0) -- Set the anchor to the previous button
	end
	
	for j = 2, MAX_LOOTS do -- create the rest of the loot frames
		frame = CreateFrame("Frame", "$parentEntry"..j, RCLootFrame, "RCLootFrameEntry")
		frame:SetID(j)
		frame:SetPoint("TOP", "$parentEntry"..(j-1), "BOTTOM")
		-- lootframe buttons
		button = CreateFrame("Button", "$parentButton1", frame, "RCLootFrame_Button"); -- Creates the first row
		button:SetID(1); -- Set the ID
		button:SetPoint("TOPLEFT", 68, -42) -- Set anchor
		button:SetWidth(66) -- set the length
		for i = 2, db.maxButtons do -- Create the rest of the buttons
			button = CreateFrame("Button", "$parentButton"..i, frame, "RCLootFrame_Button");
			button:SetWidth(66)
			button:SetID(i);
			button:SetPoint("TOPLEFT", "$parentButton"..(i-1), "TOPRIGHT", 5, 0) -- Set the anchor to the previous button
		end	
	end

end
---------- setupLoot ----------------
-- Updates the buttons and sort the
-- data to display in the lootframes.
-------------------------------------
function RCLootCouncil_LootFrame.setupLoot(table)
	-- update buttons
	for j = 1, MAX_LOOTS do
		for i = 1, db.maxButtons do
			local button = getglobal("RCLootFrameEntry"..j.."Button"..i)
			if i <= db.numButtons then -- if it should be showed
				local length = #(buttonsDB[i]["text"]) * 10 - 20; -- calculate length
				if length < 66 then length = 66 end -- minimun is 66px
				button:SetText(buttonsDB[i]["text"])
				button:SetWidth(length)
				button:Show()
				if i ~= 1 then button:SetPoint("TOPLEFT", "RCLootFrameEntry"..j.."Button"..(i-1), "TOPRIGHT", 5, 0) end -- move the buttons over aswell
			else -- hide it
				button:Hide()
			end
		end
	end
	local count = 0;
	for i = 1, #table do
		local name = GetItemInfo(table[i])
		if strlen(name or "aaaaaaaaaaaaaaaaa") > count then
			count = strlen(name or "aaaaaaaaaaaaaaaaa")
		end
	end
	-- Get and set the lootFrame width
	local lootFrameWidth = 100;
	local hoverWidth = count * 10 - 40;
	for i = 1, db.numButtons do
		if buttonsDB[i]["text"] ~= "" then
			lootFrameWidth = lootFrameWidth + getglobal("RCLootFrameEntry1Button"..i):GetWidth()
		end
	end
	if lootFrameWidth - 90 < hoverWidth then lootFrameWidth = hoverWidth + 150; end -- make sure the width doesn't get less than the length of the item
	RCLootFrame:SetWidth(lootFrameWidth)

	-- now construct the individual item lootFrames
	for i = 1, #table do
		local name, link, _, ilvl, _, _, _, _, _, texture = GetItemInfo(table[i])
		RCLootCouncil_LootFrame:SetupLootFrames(name, link, texture, ilvl, i, lootFrameWidth)
	end
	itemsLooting = table;
end

------------------ SetupLootFrames -------------
-- Prepares and shows the loot frames
------------------------------------------------
function RCLootCouncil_LootFrame:SetupLootFrames(name, iLink, iTexture, ilvl, number, length)
	local frame = getglobal("RCLootFrameEntry"..number)
	frame:SetWidth(length)
	local hoverWidth = #name * 10 - 40
	getglobal("RCLootFrameEntry"..number.."Hover2"):SetWidth(hoverWidth) -- set the mouse over link to match the item name
	-- Setup all the rest
	getglobal("RCLootFrameEntry"..number.."ItemLabel"):SetText(iLink);
	getglobal("RCLootFrameEntry"..number.."ItemLabel"):SetFont("Fonts\\FRIZQT__.TTF", 16);
	getglobal("RCLootFrameEntry"..number.."Texture"):SetTexture(iTexture);
	getglobal("RCLootFrameEntry"..number.."Ilvl"):SetText("ilvl: "..ilvl);
	getglobal("RCLootFrameEntry"..number.."Ilvl"):SetPoint("TOPRIGHT", "$parent", "TOPRIGHT", -2, -5)
	RCLootFrame:SetHeight(number * 75)
	RCLootFrame:Show()
	frame:Show();
end
---------- ShowTooltip -------------
-- Shows the loot item's tooltip
------------------------------------
function RCLootCouncil_LootFrame.ShowTooltip(id)
	if itemsLooting then
		GameTooltip:SetOwner(RCLootFrame, "ANCHOR_CURSOR")
		GameTooltip:SetHyperlink(itemsLooting[id])
		GameTooltip:Show()
	end
end

------------- toolMouseLeave ------------------------
-- Removes the tooltip when mouse leaves the area
-----------------------------------------------------
function RCLootCouncil_LootFrame.toolMouseLeave()
	GameTooltip:Hide()
end

---------- onClick ------------------
-- Sends user response to MasterLooter
-------------------------------------
function RCLootCouncil_LootFrame:onClick(response, id, button)
	getglobal("RCLootFrameEntry"..id):Hide();
	RCLootCouncil.handleResponse(response, id);	
end

----------- hide -------------------
-- Hides the loot frame 
------------------------------------
function RCLootCouncil_LootFrame.hide()
	if RCLootFrame:IsShown() then
		for i = 1, MAX_LOOTS do
			getglobal("RCLootFrameEntry"..i):Hide()
		end
		RCLootFrame:Hide()
		wipe(itemsLooting)
	end
end
